
#ifndef _INC_HCFIX
#define _INC_HCFIX

extern "C" {

struct ZKDocumentBlock
{
    wchar_t InsurerName[100 + 1];
    wchar_t InsurerID[15 + 1];
    wchar_t CardID[11 + 1];
    wchar_t DateOfIssue[8 + 1];
    wchar_t DateOfExpiry[8 + 1];
    wchar_t ChipSerialNumber[16 + 1];
    wchar_t PrintLanguage[2 + 1];
};

struct ZKFixedPersoBlock
{
    wchar_t InsurantNumber[11 + 1];
    wchar_t FamilyName[100 + 1];
    wchar_t FamilyNameLatin[100 + 1];
    wchar_t GivenName[100 + 1];
    wchar_t GivenNameLatin[100 + 1];
    wchar_t DateOfBirth[8 + 1];
};

struct ZKVariablePersoBlock
{
    wchar_t CardID[11 + 1];
    wchar_t DateOfIssue[8 + 1];
    wchar_t DateOfExpiry[8 + 1];
    bool    DateOfExpirySpecified;
    bool    IsPermanent;
};

struct ZKVariableAdminBlock
{
    wchar_t CardID[11 + 1];
    wchar_t ParentName[100 + 1];
    bool    ParentNameSpecified;
    wchar_t ParentNameLatin[100 + 1];
    bool    ParentNameLatinSpecified;
    int     Gender;
    wchar_t IDNumber[13 + 1];
    wchar_t Street[100 + 1];
    wchar_t PostNumber[5 + 1];
    bool    PostNumberSpecified;
    wchar_t Municipality[50 + 1];
    wchar_t Place[50 + 1];
    wchar_t StreetCode[9 + 1];
    wchar_t Number[10 + 1];
    wchar_t Entrance[10 + 1];
    bool    EntranceSpecified;
    wchar_t Apartment[10 + 1];
    bool    ApartmentSpecified;
    wchar_t RZZOUserRegistrationNumber[10 + 1];
    wchar_t InsuranceBasisRZZOCode[4 + 1];
    wchar_t InsuranceBasisRZZO[440 + 1];
    wchar_t CarrierRelationship[40 + 1];
    bool    CarrierRelationshipSpecified;
    int     CarrierFamilyMember;
    bool    CarrierFamilyMemberSpecified;
    wchar_t CarrierIDNumber[13 + 1];
    bool    CarrierIDNumberSpecified;
    wchar_t CarrierInsurantNumber[11 + 1];
    bool    CarrierInsurantNumberSpecified;
    wchar_t CarrierFamilyName[100 + 1];
    bool    CarrierFamilyNameSpecified;
    wchar_t CarrierFamilyNameLatin[100 + 1];
    bool    CarrierFamilyNameLatinSpecified;
    wchar_t CarrierGivenName[100 + 1];
    bool    CarrierGivenNameSpecified;
    wchar_t CarrierGivenNameLatin[100 + 1];
    bool    CarrierGivenNameLatinSpecified;
    wchar_t InsuredFrom[8 + 1];
    wchar_t CountryCode[3 + 1];
    wchar_t Country[100 + 1];
    wchar_t BookletIssuerCode[3 + 1];
    wchar_t InsurerBranch[60 + 1];
    wchar_t InsurerOffice[70 + 1];
    bool    InsurerOfficeSpecified;
    wchar_t TaxpayerName[400 + 1];
    wchar_t TaxpayerResidence[50 + 1];
    wchar_t TaxpayerNumber[9 + 1];
    bool    TaxpayerNumberSpecified;
    wchar_t TaxpayerIDNumber[13 + 1];
    bool    TaxpayerIDNumberSpecified;
    wchar_t TaxpayerActivityCode[5 + 1];
    bool    TaxpayerActivityCodeSpecified;
    wchar_t ParticipationFreeReason[3 + 1];
    bool    ParticipationFreeReasonSpecified;
};


// Error codes

#define REZ_OK 0
#define REZ_CARD_ERROR 10
#define REZ_FAIL_TO_CONVERT_ACSII_STRING 2
#define REZ_FAIL_TO_CONVERT_WIDE_STRING 3
#define REZ_HANDLE_DOES_NOT_EXIST 4
#define REZ_GENERAL_ERROR 5




// Functions

int WCToMultyByte (wchar_t* inBuffer, int inBuffLen, char* &encoded_string);
int MBToWideChar (char* inBuffer, int inBuffLen, wchar_t* &decoded_string);

int ListReadersA(bool onlyWithHC, char* mszReaders, int* cchReades);
int ListReadersW(bool onlyWithHC, wchar_t* mwszReaders, int* cchReaders);

#ifdef UNICODE
#define ListReaders     ListReadresW
#else
#define ListReaders     ListReadresA
#endif

int IsHealthCardA(char* pszReaderName, bool* bRet);
int IsHealthCardW(wchar_t* pwszReaderName, bool* bRet);

int GetErrorMessage(char* messageBuffer);

#ifdef UNICODE
#define IsHealthCard    IsHealthCardW
#else
#define IsHealthCard    IsHealthCardA
#endif

typedef unsigned int DOC_READ_SVC_HANDLE;

int AcquireDocumentReadServiceA(char* pszReaderName, int appID, DOC_READ_SVC_HANDLE* pHandle);
int AcquireDocumentReadServiceW(wchar_t* pwszReaderName, int appID, DOC_READ_SVC_HANDLE* pHandle);

#ifdef UNICODE
#define AcquireDocumentReadService  AcquireDocumentReadServiceW
#else
#define AcquireDocumentReadService  AcquireDocumentReadServiceA
#endif

int ReleaseDocumentReadService(DOC_READ_SVC_HANDLE hSvc);
int CheckDocumentReadServiceOrigin(DOC_READ_SVC_HANDLE hSvc);

int ReadZKDocumentData(DOC_READ_SVC_HANDLE hSvc, ZKDocumentBlock* pBlock);
int ReadZKFixedPersoData(DOC_READ_SVC_HANDLE hSvc, ZKFixedPersoBlock* pBlock);
int ReadZKVariablePersoData(DOC_READ_SVC_HANDLE hSvc, ZKVariablePersoBlock* pBlock);
int ReadZKVariableAdminData(DOC_READ_SVC_HANDLE hSvc, ZKVariableAdminBlock* pBlock);

int VerifyZKDocumentData(DOC_READ_SVC_HANDLE hSvc);
int VerifyZKFixedPersoData(DOC_READ_SVC_HANDLE hSvc);
int VerifyZKVariablePersoData(DOC_READ_SVC_HANDLE hSvc);
int VerifyZKVariableAdminData(DOC_READ_SVC_HANDLE hSvc);
}

#endif // _INC_HCFIX
